progress_page — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

# progress_page

Created on Jan 7, 2010

@author: tw55413

class `camelot.view.wizard.pages.progress_page.` `ProgressPage`(parent=None)

  Generic progress page for a wizard.

  Subclass and reimplement the run method. And within this run method, regulary emit the update_progress_signal and the update_maximum_signal.

  the update_maximum_signal should have as its single argument an integer value indicating the maximum of the progress bar.

  the update_progress_signal should two arguments, the first is an integer indicating the current position of the progress bar, and the second is a string telling the user what is going on.

  If required, set the title and sub_title class attribute to change the text displayed to the user.

  `run`()

    This method contains the actual action, that will be run in the model thread.

    Reimplement this method, while regulary emiting update_progress_signal and update_maximum_signal to keep the progress bar moving.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

Comments
blog comments powered by Disqus